=======
History
=======

0.2.* (2019-08)
------------------

* Change global variable to weak reference
* Remove Lock (Prepare to implement optimistic raw lock if necessary)
* Improve Priority Data Structure
* Improve Field Validation
* Use OOP to define call function
* Properer validation and typecast
* Improve Type Annotations
* Import JSON type

0.1.0 (2019-08-01)
------------------

* Init Project.
